function fun = VoltIndent(a,alpha,kappa,mu,h,b,h0,kn)
global f1 fid
%  Computes the function f for the non-linear Volterra equation
%  corresponding to indentation of a viscoelastic solid.
%
%   h(t)(1+h^(1/2)(t))=b(t)-lambda*int(h(xi)*exp((xi-t)/tau)dxi,xi=0...t)
%
%  Solves the polynomial to compute the new indentation depth
n=round((b-a)/h)+1;
% Time interval
t=a:h:b;                           
% Check n is the correct length
if length(t)~=n
    if length(t)<n
        n=n-1;
        display('n should be one less, corrected')      
    elseif length(t)>n
        n=n+1;
        display('n should be one more, corrected')
    else
        error('Vectors are not of the same length, corrected')
    end
end
f1=zeros(1,n);                      % Vector storage for indentation
f1(1)=h0;                           % Initial indentation
J=zeros(1,n);                       % Integral values
for i=1:n-1
    RHS=second(t(i+1),f1(1),alpha,kappa,mu)-alpha*mu*J(i)*exp(-t(i))-alpha*mu*h/2*f1(i)*exp(-h);  % Compute the RHS at time t+h
    g=psolve2(alpha,mu,h,RHS);      % Solves the cubic
    f1(i+1)=real(g^2);              % Indentation depth    
    % Compute int(h(xi)*exp(xi/tau),xi=0...t)       
    J(i+1)=trap4(i*h,h,f1,J(i));
end
% Display and return values NB f1 is global.
figure(1)
hold on
plot(t,f1-h0,'m')
fun=[f1(length(f1)),J(length(J))];