function fun = VoltIndentRelax(a,alpha,kappa,mu,h,b,h0,J,kn)
global f1 fid
%  Computes the function f for the non-linear Volterra equation
%  corresponding to indentation of a viscoelastic solid.
%
%   h(t)(1+h^(1/2)(t))=b(t)-lambda*int(h(t=xi)*exp((xi-t)/tau)dxi
%
%  Solves the polynomial to compute the new indentation depth
n=round((b-1/kappa)/h)+1;
% Set the time interval
t=1/kappa:h:b;              
% Check n is the correct length
if length(t)~=n
    if length(t)<n
        n=n-1;
        display('n should be one less')      
    elseif length(t)>n
        n=n+1;
        display('n should be one more, corrected')
    else
        error('Vectors are not of the same length, corrected')
    end
end
f2=zeros(1,n);              % Initialise f2
f2(1)=f1(length(f1));       % Initial indentation
for i=1:n-h
    f1length=length(f1);
    RHS=third(t(i+1),h0,alpha,kappa,mu)-alpha*mu*J(i)*exp(-t(i))-alpha*mu*h/2*f2(i)*exp(-h);  % Compute the RHS    
    g=psolve2(alpha,mu,h,RHS); 
    f2(i+1)=real(g^2);      % f(t)
    f1(f1length+1)=f2(i+1);
    % Compute the integral  
    J(i+1)=trap4(1/kappa+i*h,h,f1,J(i));
end
figure(1)
hold on
plot(t,f2-h0,'m')
fun=f2;