% Script for the non-linear Volterra solver
% Non-dimensional this time
clear all
global f1
% Material parameters
G1=10^6;            % Viscoelastic modulus
G2=10^5;            % Viscoelastic modulus
tau=10;             % Relaxation time (s)
% System parameters 
ai=0;               % Start time (s)
hi=10^(-7);         % Step size, method has error order h^2 (s)
R=8*10^(-6);        % Radius of probe (m)
nu=0.5;             % Poisson's ratio
V=1*10^(-9);        % Velocity of fixed end during ramp phase (m/s)
k=0.9*10^(0);       % Stiffness of spring/cantilever (N/m)
gamma=1;            % Time at switch off (s)
bi=gamma;%10*tau;   % End time (s)
F=0*10^(-9);        % Hertzian preload
% Starting indentation given the preload
hi0=1/R*(3/8*F*R*(G1+G2)/(G1*G2))^(2/3);
A=3*(1-nu)/(8*sqrt(R));        
n=bi/hi+1;          % Number of steps
% Non-dimensionalisation
alpha=A*k/(G1*(V*gamma)^(1/2));
kappa=tau/gamma;
mu=G1/G2;
h=hi/tau;
h0=hi0/(V*gamma);
a=ai/tau;
b=bi/tau;
kn=k/(V*gamma*G1);
L=alpha*(1+mu);
RHS=alpha*(1+mu)*(1+h0);
psi=(108*RHS-8*L^3+12*sqrt(81*RHS^2-12*RHS*L^3))^(1/3);
hinf=(real(psi/6+2*L^2/(3*psi)-L/3))^2-h0;
% Some simple calculations and plotting of Drive velocity
t=[0,1/kappa];
x=[0, 1];
t1=[1/kappa,b];
x1=[1, 1];
han1=figure(1);
plot(t,x,'r-');hold on;plot(t1,x1,'r-')
xlabel('Time/(Relaxation time),   (t/\tau_c)')
ylabel('Indentation depth/Fixed end motion,   h/(V\gamma)')
hold on
if b<=1/kappa
%   The drive solver
    hdrive=VoltIndent(a,alpha,kappa,mu,h,b,h0,kn);    
else
%   The drive solver
    hdrive=VoltIndent(a,alpha,kappa,mu,h,1/kappa,h0,kn);    
%   The relaxation solver
    hrelax=VoltIndentRelax(a,alpha,kappa,mu,h,b,h0,hdrive(2),kn);       
end